pub trait MacroResult {
// Required method
fn into_result(self) -> Result<TokenStream>;
// Provided method
fn into_stream(self) -> TokenStream
where Self: Sized { ... }
}Expand description
Helper trait describing values which may be returned by macro implementation methods used by this crate’s macros.
Required Methods
Sourcefn into_result(self) -> Result<TokenStream>
fn into_result(self) -> Result<TokenStream>
Convert this result into a Result for further processing / validation.
Provided Methods
Sourcefn into_stream(self) -> TokenStreamwhere
Self: Sized,
fn into_stream(self) -> TokenStreamwhere
Self: Sized,
Convert this result into a proc_macro::TokenStream, ready to return
from a native proc_macro implementation.
If into_result() would return an Err, this method should instead
generate a compile_error! invocation to nicely report the error.
This method is available if synstructure is built with the
"proc-macro" feature.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl MacroResult for TokenStream
Available on crate feature proc-macro and not (WebAssembly and (target_os=unknown or WASI)) only.
impl MacroResult for TokenStream
Available on crate feature
proc-macro and not (WebAssembly and (target_os=unknown or WASI)) only.